summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/handle.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libalpm/handle.h')
-rw-r--r--lib/libalpm/handle.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/libalpm/handle.h b/lib/libalpm/handle.h
index 6f5ee58a..35fe4877 100644
--- a/lib/libalpm/handle.h
+++ b/lib/libalpm/handle.h
@@ -32,8 +32,8 @@
struct __alpm_handle_t {
/* internal usage */
- pmdb_t *db_local; /* local db pointer */
- alpm_list_t *dbs_sync; /* List of (pmdb_t *) */
+ alpm_db_t *db_local; /* local db pointer */
+ alpm_list_t *dbs_sync; /* List of (alpm_db_t *) */
FILE *logstream; /* log file stream pointer */
FILE *lckstream; /* lock file stream pointer if one exists */
pmtrans_t *trans;